@@ -170,7 +170,7 @@ void ToolTipManager::showToolTip( QModelIndex menuItem )
     }
 
     // the ownership of tip is transferred to KToolTip
-    KToolTip::showTip(QPoint(x, y), tip);
+    KToolTip::showTip(QPoint(x, y), tip, d->view->nativeParentWidget()->windowHandle());
 }
 
 QWidget * ToolTipManager::createTipContent( QModelIndex item )
